from emod_api import schema_to_class as s2c
from emodpy_tbhiv.interventions import purge_campaign_event

def HIV(
        camp,
        time_offset=0,
        disease= 'HIV',
        reps= -1,
        interval= 1,
        start_day=0,
        nodeIDs=[],
        event_name='HIV Incidence'):

    """
    Create a scheduled campaign event that issues an OutbreakIndividualTBorHIV intervention. Useful for seeding interventions in TBHIV_SIM.

    Args:

        camp: The :py:obj:`emod_api:emod_api.campaign` module instance which serves as the campaign accumulator.
        
        time_offset: ... Defaults to 0.
        disease: "TB" or "HIV". Default is "HIV".
        reps: Number of repetitions (integer). Defaults to no repetition.
        interval: Timesteps between repetitions, if reps is set. Defaults to every day.

        start_day: The timestep when this campaign event takes effect. Defaults to 1.
        duration: How long the campaign event remains in effect. Defaults to forever.
        property_restrictions_list: Optiional list of Individual Properties to limit the intervention to.
        nodeIDs: Optiona list of node ids to target. Defaults to all.

        black_period: Undocumented.
        black_trigger: Undocumented.
        event_name: Undocumented.

    Returns:

        New campaign event that can be added to the campaign.

    """

    schema_path = camp.schema_path
    iv_name = "OutbreakIndividualTBorHIV"
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "GroupInterventionDistributionEventCoordinatorHIV", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return ""
    intervention = s2c.get_class_with_defaults( iv_name, schema_path )

    event.Start_Day = float(start_day)
    #event.Event_Name = event_name
    coordinator.Time_Offset = time_offset
    coordinator.Number_Repetitions = reps
    coordinator.Timesteps_Between_Repetitions = interval

    event.Event_Coordinator_Config = coordinator
    coordinator.Intervention_Config = intervention
    intervention.Infection_Type = disease
    purge_campaign_event( event )
    return event

def new_intervention_as_file( camp, filename="hiv.json" ):
    camp.add( HIV( camp ) )
    camp.save( filename )
    return filename

